package ACL2::Proceso::UsoHipotesis;
use base ACL2::Proceso;

=head1 NAME

ACL2::Proceso::UsoHipotesis - uso de hipE<oacute>tesis por sustitución o fertilizaciE<oacute>n cruzada

=head1 FUNCTIONS

=cut

#
#    Clase UsoHipotesis: uso de hipótesis o fertilización cruzada
#    Copyright (C) 2006-2008 Antonio García Domínguez
#    $Id$
#
#    This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

use strict;
use warnings;
use utf8;

use ACL2::Orden;
use ACL2::Proceso::Fabrica;

BEGIN {
ACL2::Proceso::Fabrica->registrar
    (
     __PACKAGE__,
     sub {
	 return ACL2::Proceso::UsoHipotesis->_identificar(@_);
     }
     );
}

sub escribir_xml_cabecera {
    my ($this, $writer) = @_;

    $writer->startTag($this->{metodo} eq "substituting" 
		      ? ACL2::Tags::HYPOTH_TAG : ACL2::Tags::CROSSFERT_TAG);

    $writer->startTag(ACL2::Tags::REPLACEMENTS_TAG);
    $writer->emptyTag(ACL2::Tags::REPLACEMENT_TAG, 
		      "from" => $this->{origen}, 
		      "to" => $this->{destino});
    $writer->endTag(ACL2::Tags::REPLACEMENTS_TAG);
    
    ACL2::Orden->salida_parrafos($writer, $this->{salida});
}

sub escribir_xml_final {
    my ($this, $writer) = @_;

    $writer->endTag($this->{metodo} eq "substituting" 
		    ? ACL2::Tags::HYPOTH_TAG : ACL2::Tags::CROSSFERT_TAG);
}

sub _identificar
{
    my ($paquete, $salida) = @_;
    my %res      = ();

    # Puede usarse "second hypothesis", p.ej.
    # Además, se puede o bien sustituir o bien hacer fertilización cruzada
    $salida =~ /^(?-x:\s*We now use the .*?hypothesis by (substituting|cross-fertilizing) )
	(.*?) \s for \s (.*?) 				  # Sustituciones de interés
	(?-x: and throwing (?:[^\.]+?)\.)/ox or return undef;

    $res{metodo}  = $1;
    $res{origen}  = $2;
    $res{destino} = $3;
    $res{salida}  = substr $salida, $-[0], $+[0] - $-[0];
    
    return \%res;
}

1;
